@@ -1,8 +1,8 @@
 import platform
 
-__version__ = "0.1"
+__version__ = "0.1.2"
 
 if platform.system() != "Windows":
     raise OSError
 
-from . import __main__
+from main import CWInput, Key, Keys
